# coding: utf-8

"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces. Please note that the Python client library follows Python's naming convention of snake casing for fields, even though they may appear in camel case in the API specification. <p><b>By default this api documentation targets the koverse production server at 'api.app.koverse.com' You can provide the hostname of your koverse instance to this documentation page via the 'host' query param.</p> <p><b>For example providing host - https://koverse-docs.saic.com/api?host=api.myHost.com, will update requests to target the provided host.</b></p> <p><b>Authentication request example with provided host - https://api.myHost.com/authentication</b></p>

    The version of the OpenAPI document: 4.137.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AuditLogEvent(BaseModel):
    """
    AuditLogEvent
    """ # noqa: E501
    id: StrictStr = Field(description="event ID")
    type: StrictStr
    user_id: Optional[StrictStr] = Field(default=None, description="user ID if available", alias="userId")
    timestamp_ms: StrictInt = Field(description="event timestamp - UTC - Required. Number of milliseconds since the Unix epoch (January 1, 1970, 00:00:00 UTC).", alias="timestampMs")
    description: Optional[StrictStr] = Field(default=None, description="details of the audit log event")
    source_ip: Optional[StrictStr] = Field(default=None, description="IP address of the user machine - optional", alias="sourceIP")
    dataset_id: StrictStr = Field(description="dataset ID", alias="datasetId")
    actor: Optional[StrictStr] = Field(default=None, description="The user who requested the action or `KDP Service` if initiated by KDP.")
    details: Optional[Dict[str, Any]] = Field(default=None, description="details of the audit log event")
    __properties: ClassVar[List[str]] = ["id", "type", "userId", "timestampMs", "description", "sourceIP", "datasetId", "actor", "details"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['Login', 'UserProfileManagement', 'UserManagement', 'AuditLogConfigManagement', 'WorkspaceManagement', 'AttributeManagement', 'GroupManagement', 'DatasetManagement', 'BillingPlanManagement', 'DataDownload', 'IdentityProviderManagement', 'WriteRecords']):
            raise ValueError("must be one of enum values ('Login', 'UserProfileManagement', 'UserManagement', 'AuditLogConfigManagement', 'WorkspaceManagement', 'AttributeManagement', 'GroupManagement', 'DatasetManagement', 'BillingPlanManagement', 'DataDownload', 'IdentityProviderManagement', 'WriteRecords')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AuditLogEvent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AuditLogEvent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "type": obj.get("type"),
            "userId": obj.get("userId"),
            "timestampMs": obj.get("timestampMs"),
            "description": obj.get("description"),
            "sourceIP": obj.get("sourceIP"),
            "datasetId": obj.get("datasetId"),
            "actor": obj.get("actor"),
            "details": obj.get("details")
        })
        return _obj


